==> haskell-data-binary-ieee754-0.4.4-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-binary-ieee754.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-binary-ieee754
version: 0.4.4
id: data-binary-ieee754-0.4.4-F3YRhJd3kvlDf64vOl9RIA
key: data-binary-ieee754-0.4.4-F3YRhJd3kvlDf64vOl9RIA
license: MIT
maintainer: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/data-binary-ieee754/
synopsis: Parser/Serialiser for IEEE-754 floating-point values
description:
    Convert Float and Decimal values to/from raw octets.
category: Data
author: John Millikin <jmillikin@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Binary.IEEE754
abi: 3ba71c5a4d63b57772cd0af9b7fec92c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/data-binary-ieee754-0.4.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/data-binary-ieee754-0.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/data-binary-ieee754-0.4.4
hs-libraries: HSdata-binary-ieee754-0.4.4-F3YRhJd3kvlDf64vOl9RIA
depends:
    base-4.10.1.0 binary-0.8.5.1
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             binary-0.8.5.1=efb65bc450356b9ea572733928ffb43f
haddock-interfaces: /usr/share/doc/haskell-data-binary-ieee754/html/data-binary-ieee754.haddock
haddock-html: /usr/share/doc/haskell-data-binary-ieee754/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-binary-ieee754-0.4.4-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-binary-ieee754.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-binary-ieee754
version: 0.4.4
id: data-binary-ieee754-0.4.4-GMEnBfyxjqq6rJmTySXper
key: data-binary-ieee754-0.4.4-GMEnBfyxjqq6rJmTySXper
license: MIT
maintainer: John Millikin <jmillikin@gmail.com>
author: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/data-binary-ieee754/
synopsis: Parser/Serialiser for IEEE-754 floating-point values
description:
    Convert Float and Decimal values to/from raw octets.
category: Data
abi: e4629bf0c2a1ba49137646cd720e96ee
exposed: True
exposed-modules:
    Data.Binary.IEEE754
import-dirs: /usr/lib/ghc-8.4.2/site-local/data-binary-ieee754-0.4.4
library-dirs: /usr/lib/ghc-8.4.2/site-local/data-binary-ieee754-0.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/data-binary-ieee754-0.4.4
hs-libraries: HSdata-binary-ieee754-0.4.4-GMEnBfyxjqq6rJmTySXper
depends:
    base-4.11.1.0 binary-0.8.5.1
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             binary-0.8.5.1=253349ae905e3b03d89d37316bf920b7
haddock-interfaces: /usr/share/doc/haskell-data-binary-ieee754/html/data-binary-ieee754.haddock
haddock-html: /usr/share/doc/haskell-data-binary-ieee754/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
